@@ -48,7 +48,7 @@ test_that("tsearchn gives the expected output", {
   ## tsearchn_delaunayn to be called
   tfake <- matrix(1:3, 1, 3)
   class(tfake) <- "delaunayn"
-  expect_error(tsearchn(NA, tfake, matrix(1:2, 1, 2)), "Delaunay triangulation has no delaunayn attribute")
+  expect_error(suppressWarnings(tsearchn(NA, tfake, matrix(1:2, 1, 2))), "Delaunay triangulation has no delaunayn attribute")
 
   x <- cbind(c(-1, -1, 1),
              c(-1, 1, -1))
